summaryrefslogtreecommitdiff
path: root/drivers/net/ks8851_mll.c
diff options
context:
space:
mode:
authorJoe Hershberger <joe.hershberger@ni.com>2015-04-08 01:41:06 -0500
committerSimon Glass <sjg@chromium.org>2015-04-18 11:11:33 -0600
commit1fd92db83d399ff7918e51ba84bc73d2466b5eb6 (patch)
tree6d42cf4bc236ce7024c179e492957d9a1316f644 /drivers/net/ks8851_mll.c
parent1203fcceec113d502995f7242d7e1be09d373e80 (diff)
downloadu-boot-imx-1fd92db83d399ff7918e51ba84bc73d2466b5eb6.zip
u-boot-imx-1fd92db83d399ff7918e51ba84bc73d2466b5eb6.tar.gz
u-boot-imx-1fd92db83d399ff7918e51ba84bc73d2466b5eb6.tar.bz2
net: cosmetic: Fix var naming net <-> eth drivers
Update the naming convention used in the network stack functions and variables that Ethernet drivers use to interact with it. This cleans up the temporary hacks that were added to this interface along with the DM support. This patch has a few remaining checkpatch.pl failures that would be out of the scope of this patch to fix (drivers that are in gross violation of checkpatch.pl). Signed-off-by: Joe Hershberger <joe.hershberger@ni.com> Acked-by: Simon Glass <sjg@chromium.org>
Diffstat (limited to 'drivers/net/ks8851_mll.c')
-rw-r--r--drivers/net/ks8851_mll.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/drivers/net/ks8851_mll.c b/drivers/net/ks8851_mll.c
index 05e5b14..5b4c5b0 100644
--- a/drivers/net/ks8851_mll.c
+++ b/drivers/net/ks8851_mll.c
@@ -321,8 +321,8 @@ static void ks_rcv(struct eth_device *dev, uchar **pv_data)
/* read data block including CRC 4 bytes */
ks_read_qmu(dev, (u16 *)(*pv_data), frame_hdr->len);
- /* NetRxPackets buffer size is ok (*pv_data pointer) */
- NetReceive(*pv_data, frame_hdr->len);
+ /* net_rx_packets buffer size is ok (*pv_data) */
+ net_process_received_packet(*pv_data, frame_hdr->len);
pv_data++;
} else {
ks_wrreg16(dev, KS_RXQCR, (ks->rc_rxqcr | RXQCR_RRXEF));
@@ -573,7 +573,7 @@ static int ks8851_mll_recv(struct eth_device *dev)
ks_wrreg16(dev, KS_ISR, status);
if ((status & IRQ_RXI))
- ks_rcv(dev, (uchar **)NetRxPackets);
+ ks_rcv(dev, (uchar **)net_rx_packets);
if ((status & IRQ_LDI)) {
u16 pmecr = ks_rdreg16(dev, KS_PMECR);